You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by lu...@apache.org on 2012/08/18 20:08:58 UTC

svn commit: r1374628 - in /commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation: UnivariateDifferentiable.java UnivariateDifferential.java UnivariateDifferentiator.java package-info.java

Author: luc
Date: Sat Aug 18 18:08:57 2012
New Revision: 1374628

URL: http://svn.apache.org/viewvc?rev=1374628&view=rev
Log:
renamed UnivariateDifferential into UnivariateDifferentiable

Added:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java   (contents, props changed)
      - copied, changed from r1374627, commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferential.java
Removed:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferential.java
Modified:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiator.java
    commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/package-info.java

Copied: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java (from r1374627, commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferential.java)
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java?p2=commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java&p1=commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferential.java&r1=1374627&r2=1374628&rev=1374628&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiator.java Sat Aug 18 18:08:57 2012
@@ -29,6 +29,6 @@ public interface UnivariateDifferentiato
      * @param function function to differentiate
      * @return differential function
      */
-    UnivariateDifferential differentiate(UnivariateFunction function);
+    UnivariateDifferentiable differentiate(UnivariateFunction function);
 
 }

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/package-info.java?rev=1374628&r1=1374627&r2=1374628&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/package-info.java Sat Aug 18 18:08:57 2012
@@ -22,11 +22,11 @@
  *   The core class is {@link DerivativeStructure} which holds the value and
  *   the differentials of a function. This class handles some arbitrary number
  *   of free parameters and arbitrary derivation order. It is used both as
- *   the input and the output type for the {@link UnivariateDifferential}
+ *   the input and the output type for the {@link UnivariateDifferentiable}
  *   interface. Any differentiable function should implement this interface.
  * </p>
  * <p>
- *   The {@link UnivariateDifferentiator} interface defines a way to differentation
+ *   The {@link UnivariateDifferentiator} interface defines a way to differentiation
  *   a simple {@link org.apache.commons.math3.analysis.UnivariateFunction
  *   univariate function} and get a {@link differential function}.
  * </p>
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferential.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java Sat Aug 18 18:08:57 2012
@@ -27,35 +27,14 @@ import org.apache.commons.math3.analysis
  * @since 3.1
  * @version $Id$
  */
-public interface UnivariateDifferential {
-
-    /** Get the primitive function associated with this differential.
-     * <p>Each {@link UnivariateDifferential} instance is tightly bound
-     * to an {@link UnivariateDifferentiable} instance. If the state of
-     * the primitive instance changes in any way that affects the
-     * differential computation, this binding allows this change to
-     * be immediately seen by the derivative instance, there is no need
-     * to differentiate the primitive again. The existing instance is aware
-     * of the primitive changes.</p>
-     * <p>In other words in the following code snippet, the three values
-     * f1, f2 and f3 should be equal (at least at machine tolerance level)</p>
-     * <pre>
-     *    UnivariateDifferential derivative = differentiator.differentiate(derivable);
-     *    derivable.someFunctionThatMutatesHeavilyTheInstance();
-     *    double f1 = derivable.f(t);
-     *    double f2 = derivative.getPrimitive().f(t);
-     *    double f3 = derivative.f(new DerivativeStructure(variables, order, index, t)).getValue();
-     * </pre>
-     * @return primitive function bound to this derivative
-     */
-    UnivariateFunction getPrimitive();
+public interface UnivariateDifferentiable extends UnivariateFunction {
 
     /** Simple mathematical function.
      * <p>{@link UnivariateDifferential} classes compute both the
      * value and the first derivative of the function.</p>
      * @param t function input value
      * @return function result
      */
-    DerivativeStructure f(DerivativeStructure t);
+    DerivativeStructure value(DerivativeStructure t);
 
 }

Propchange: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiable.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"
@@ -27,35 +27,14 @@ import org.apache.commons.math3.analysis
 
     /** Simple mathematical function.
-     * <p>{@link UnivariateDifferential} classes compute both the
+     * <p>{@link UnivariateDifferentiable} classes compute both the
      * value and the first derivative of the function.</p>
      * @param t function input value

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/analysis/differentiation/UnivariateDifferentiator.java?rev=1374628&r1=1374627&r2=1374628&view=diff
==============================================================================